@@ -18,7 +18,7 @@ class ServiceError(Exception):
         super().__init__(message)
 
 
-def _get_oidc_token(audience):
+def get_auth_header(audience):
     if os.getenv("LOCAL"):
         from subprocess import Popen, PIPE
 
@@ -32,17 +32,17 @@ def _get_oidc_token(audience):
         "/computeMetadata/v1/instance/service-accounts/default/identity"
         f"?audience={audience}"
     )
-    return requests.get(
+    token = requests.get(
         url=token_url, headers={"Metadata-Flavor": "Google"},
     ).content.decode()
+    return {"Authorization": "Bearer " + token}
 
 
 def call(name, data=None):
     domain = f"https://{FUNCTION_REGION}-{GCP_PROJECT}.cloudfunctions.net"
     url = urljoin(domain, name)
-    headers = {"Authorization": "Bearer " + _get_oidc_token(url)}
-    logging.info("Service call: %s %s", name, data)
-    r = requests.post(url, headers=headers, json=data)
+    logging.info("CALL: %s %s", name, data)
+    r = requests.post(url, headers=get_auth_header(url), json=data)
     r.raise_for_status()
     return r.json()
 
@@ -54,3 +54,7 @@ def user_info(request):
             encoded_user_info += "=="
         return json.loads(urlsafe_b64decode(encoded_user_info))
     return None
+
+
+def response_message(message):
+    return {"message": message}
